#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from gabbi.handlers import base


def gabbi_response_handlers():
    return [CustomResponseHandler]


class CustomResponseHandler(base.ResponseHandler):

    test_key_suffix = 'custom'
    test_key_value = []

    def action(self, test, item, value=None):
        test.assertTrue(item in test.output)
